meta.py — Rucio 1.12.2 documentation

# meta.py

`GET` `/meta`

  > List all keys.

  Example request:

      GET /meta HTTP/1.1

  Example response:

      HTTP/1.1 200 OK
      Vary: Accept
      Content-Type: 'application/json'

`POST` `/meta`

  > Create a new allowed key (value is NULL).

  Example request:

      POST /meta HTTP/1.1

  Example response:

      HTTP/1.1 200 OK
      Vary: Accept
      Content-Type:

  Status Codes: | 400 Bad Request – ‘ValueError’: ‘Cannot decode json parameter list’ 409 Conflict – ‘Duplicate’: e[0][0] 400 Bad Request – ‘UnsupportedValueType’: e[0][0] 500 Internal Server Error – e.__class__.__name__: e.args[0][0]

`GET` `/meta`

  > List all values for a key.

  Example request:

      GET /meta HTTP/1.1

  Example response:

      HTTP/1.1 200 OK
      Vary: Accept
      Content-Type: 'application/json'

`POST` `/meta`

  > Create a new value for a key.

  Example request:

      POST /meta HTTP/1.1

  Example response:

      HTTP/1.1 200 OK
      Vary: Accept
      Content-Type:

  Status Codes: | 400 Bad Request – ‘ValueError’: ‘Cannot decode json parameter list’ 409 Conflict – ‘Duplicate’: e[0][0] 400 Bad Request – ‘InvalidValueForKey’: e[0][0] 400 Bad Request – ‘KeyNotFound’: e[0][0] 500 Internal Server Error – e.__class__.__name__: e.args[0][0]